![CircleCI](https://circleci.com/gh/linalgo/annotate-sdk.svg?style=svg&circle-token=ef87d896267f3200b095b04954eb8f382ccbd884)

# linalgo-annotate

linalgo-annotate is a python module for natural language processing compatible with the 
[web annotation data model](https://www.w3.org/TR/annotation-model/)

## Documentation

The documentation is available [here](https://linalgo.github.io/annotate-sdk/)

## installation 

```
git clone https://github.com/linalgo/annotate-sdk.git
cd linalgo-annotate
pip install .
```

## test

```
pytest
```
